# Flask_blog
A small blog developed in python using Flask https://flask.palletsprojects.com/en/1.1.x/tutorial/

In this branch a new database system is used, based on the ORM package Flask-sqlalchemy and Flask-migrate to migrate databases. A login manager using flask-login is also used. All according to https://blog.miguelgrinberg.com/post/the-flask-mega-tutorial-part-i-hello-world
